var _MIME = require("dr-js/library/common/module/MIME");
var _function = require("dr-js/library/node/file/function");
var _Buffer = require("dr-js/library/node/data/Buffer");
var _Server = require("dr-js/library/node/server/Server");
var _Common = require("dr-js/library/node/server/Responder/Common");
var _Send = require("dr-js/library/node/server/Responder/Send");
var _Router = require("dr-js/library/node/server/Responder/Router");
var _routeList = require("dr-server/library/responder/routeList");
var _dev__ = require("./__dev__");
var _syncTask = require("./syncTask");
exports.configureServerResponder = (async ({server, option, logger, urlSnapshotTask, taskRunner, taskRunnerDebugOnly}) => {
  const responderLogEnd = (0, _Common.createResponderLogEnd)(logger.add);
  const routeMap = (0, _Router.createRouteMap)([ [ [ "/nginx-sync-snapshot", "/nginx-sync-snapshot.png" ], "GET", async store => {
    const {routeFile} = await (0, _syncTask.doSyncTask)(store, {
      logger,
      urlSnapshotTask,
      taskRunner
    });
    return (0, _Common.responderEndWithStatusCode)(store, {
      statusCode: 200,
      headerMap: {
        "x-accel-redirect": encodeURI(routeFile)
      }
    });
  } ], [ [ "/debug-sync-snapshot", "/debug-sync-snapshot.png" ], "GET", async store => {
    const {pathFile} = await (0, _syncTask.doSyncTask)(store, {
      logger,
      urlSnapshotTask,
      taskRunner
    });
    store.response.setHeader("access-control-allow-origin", "*");
    return (0, _Send.responderSendBuffer)(store, {
      buffer: await (0, _function.readFileAsync)(pathFile),
      type: _MIME.BASIC_EXTENSION_MAP.png
    });
  } ], [ "/task", "POST", async store => ((store, inputData) => {
    const task = taskRunner.startTask(inputData);
    logger.add(`[Task|start] ${task.id}`);
    return (0, _Send.responderSendJSON)(store, {
      object: {
        taskId: task.id
      }
    });
  })(store, JSON.parse(await (0, _Buffer.receiveBufferAsync)(store.request))) ], [ "/task/:task-id", "GET", store => ((store, taskId) => {
    const task = taskRunner.getTaskState(taskId);
    if (!task) return (0, _Send.responderSendJSON)(store, {
      object: {}
    });
    const {error, progress = 1} = task;
    const taskStatus = {
      taskId,
      error: error && error.toString(),
      progress
    };
    logger.add(`[Task|status] ${JSON.stringify(taskStatus)}`);
    return (0, _Send.responderSendJSON)(store, {
      object: taskStatus
    });
  })(store, (0, _Router.getRouteParam)(store, "task-id")) ], [ "/task/:task-id", "DELETE", store => ((store, taskId) => {
    taskRunner.endTask(taskId);
    logger.add(`[Task|delete] ${taskId}`);
    return (0, _Common.responderEnd)(store);
  })(store, (0, _Router.getRouteParam)(store, "task-id")) ], [ [ "/", "/status" ], "GET", store => {
    const {url: {searchParams}} = store.getState();
    const isVerbose = searchParams.has("verbose");
    const isPretty = isVerbose && searchParams.has("pretty");
    let taskStatusList = taskRunner.getStatus({
      isVerbose
    });
    isPretty && (taskStatusList = taskStatusList.map(taskStatus => taskStatus.taskStateList.map(([id, state]) => `[${state.error || `${state.progress || 0}%`}] ${id}`)));
    logger.add(`[Status] ${JSON.stringify({
      isVerbose,
      isPretty,
      taskStatusListLength: taskStatusList.length
    })}`);
    (0, _Send.responderSendJSON)(store, {
      object: taskStatusList
    });
  } ], taskRunnerDebugOnly && [ [ "/favicon", "/favicon.ico" ], "GET", (0, _Send.createResponderFavicon)() ], taskRunnerDebugOnly && [ [ "/route-list" ], "GET", (0, _routeList.createResponderRouteList)(() => routeMap) ], taskRunnerDebugOnly && [ "/debug", "GET", _dev__.responderSendDebugPage ], taskRunnerDebugOnly && [ "/debug-sync-task", "POST", async store => {
    const inputData = JSON.parse(await (0, _Buffer.receiveBufferAsync)(store.request));
    logger.add(`[Task|sync] start: ${JSON.stringify(inputData)}`);
    const {id: taskId, promise: taskPromise} = taskRunner.startTask(inputData);
    taskPromise && await taskPromise;
    const {error, progress = 1} = taskRunner.getTaskState(taskId);
    const taskStatus = {
      taskId,
      error: error && error.toString(),
      progress
    };
    logger.add(`[Task|sync] end: ${JSON.stringify(taskStatus)}`);
    return (0, _Send.responderSendJSON)(store, {
      object: taskStatus
    });
  } ] ].filter(Boolean));
  server.on("request", (0, _Server.createRequestListener)({
    responderList: [ (0, _Common.createResponderLog)(logger.add), (0, _Common.createResponderParseURL)(option), (0, _Router.createResponderRouter)(routeMap) ],
    responderEnd: store => {
      (0, _Common.responderEnd)(store);
      responderLogEnd(store);
    }
  }));
});