var _ExitListener = require("dr-js/library/node/system/ExitListener");
var _taskRunner = require("./taskRunner");
exports.configureTaskRunner = (async ({logger, urlSnapshotApp, urlServerPingTest, taskRunnerCount: clusterSize, taskRunnerDebugOnly}) => {
  logger = {
    ...logger,
    add: (func => {
      let prevTime = Date.now();
      return (...args) => {
        const time = Date.now();
        func(`[+${time - prevTime}ms]`, ...args);
        prevTime = time;
      };
    })(logger.add)
  };
  const puppeteerBrowser = taskRunnerDebugOnly ? void 0 : await (0, _taskRunner.initPuppeteerBrowser)({
    logger
  });
  const taskRunner = await (taskRunnerDebugOnly ? _taskRunner.createTaskRunnerDebug : _taskRunner.createTaskRunnerPuppeteer)({
    urlSnapshotApp,
    urlServerPingTest,
    puppeteerBrowser,
    clusterSize,
    logger
  });
  (0, _ExitListener.addExitListenerAsync)(async () => {
    await taskRunner.clear();
    puppeteerBrowser && await (0, _taskRunner.clearPuppeteerBrowser)({
      puppeteerBrowser
    });
  });
  const taskEndToken = setInterval(() => taskRunner.autoEndTask(30), 3e4);
  (0, _ExitListener.addExitListenerSync)(() => clearInterval(taskEndToken));
  return taskRunner;
});