var _filePid = require("dr-server/library/configure/filePid");
var _logger = require("dr-server/library/configure/logger");
var _serverBase = require("dr-server/library/configure/serverBase");
var _configureTaskRunner = require("./configureTaskRunner");
var _configureServerResponder = require("./configureServerResponder");
var _option = require("./option");
var _package = require("../package.json");
(async () => {
  const optionData = await (0, _option.parseOption)();
  const hostname = optionData.getSingleOptionOptional("hostname");
  hostname ? await (async (hostname, {getOptionOptional, getSingleOption, getSingleOptionOptional}) => {
    await (0, _filePid.configureFilePid)({
      filePid: getSingleOptionOptional("file-pid"),
      shouldIgnoreExistPid: getSingleOptionOptional("pid-ignore-exist")
    });
    const isHttps = getOptionOptional("https");
    const {server, start, option} = await (0, _serverBase.configureServerBase)({
      protocol: isHttps ? "https:" : "http:",
      hostname: getSingleOption("hostname"),
      port: getSingleOption("port"),
      fileSSLKey: getSingleOptionOptional("file-SSL-key"),
      fileSSLCert: getSingleOptionOptional("file-SSL-cert"),
      fileSSLChain: getSingleOptionOptional("file-SSL-chain"),
      fileSSLDHParam: getSingleOptionOptional("file-SSL-dhparam")
    });
    const logger = await (0, _logger.configureLogger)({
      pathLogDirectory: getSingleOptionOptional("path-log"),
      prefixLogFile: getSingleOptionOptional("prefix-log-file")
    });
    const urlServerPingTest = getSingleOption("url-server-ping-test");
    const urlSnapshotApp = getSingleOption("url-snapshot-app");
    const urlSnapshotTask = getSingleOption("url-snapshot-task");
    const taskRunnerCount = getSingleOption("task-runner-count");
    const taskRunnerDebugOnly = getOptionOptional("task-runner-debug-only");
    const taskRunner = await (0, _configureTaskRunner.configureTaskRunner)({
      logger,
      urlSnapshotApp,
      urlServerPingTest,
      taskRunnerCount,
      taskRunnerDebugOnly
    });
    await (0, _configureServerResponder.configureServerResponder)({
      server,
      option,
      logger,
      urlSnapshotTask,
      taskRunner,
      taskRunnerDebugOnly
    });
    start();
    logger.add(`[SERVER UP] pid: ${process.pid}, running at: ${option.baseUrl}`);
  })(0, optionData).catch(error => {
    console.warn("[Error] server:", error.stack || error);
    process.exit(2);
  }) : optionData.getOptionOptional("version") ? console.log(JSON.stringify({
    packageName: _package.name,
    packageVersion: _package.version
  }, null, "  ")) : console.log((0, _option.formatUsage)());
})().catch(error => {
  console.warn((0, _option.formatUsage)(error.stack || error, "simple"));
  process.exit(1);
});