var _path = require("path");
var _fs = require("fs");
var _util = require("util");
var _url = require("url");
var _time = require("dr-js/library/common/time");
var _net = require("dr-js/library/node/net");
var _File = require("dr-js/library/node/file/File");
var _Directory = require("dr-js/library/node/file/Directory");
const utimesAsync = (0, _util.promisify)(_fs.utimes);
const unlinkAsync = (0, _util.promisify)(_fs.unlink);
exports.doSyncTask = (async (store, {logger, urlSnapshotTask, taskRunner}) => {
  const inputData = await fetchSyncTaskInputData(store.getState().url.searchParams, store.request.headers, urlSnapshotTask);
  const {taskList: [{fileName, fileNamePrefix}], pathOutput, routeOutput} = inputData;
  const pathOutputStat = await (0, _File.getPathStat)(pathOutput);
  const pathFile = (0, _path.join)(pathOutput, fileName);
  if (pathOutputStat.isDirectory() && (await (0, _File.getPathStat)(pathFile)).isFile()) {
    logger.add(`[Task|sync] exist: ${fileName}`);
    const timestamp = (0, _time.getTimestamp)();
    await utimesAsync(pathFile, timestamp, timestamp);
  } else {
    pathOutputStat.isDirectory() ? await deleteFileWithPrefix(pathOutput, fileNamePrefix).catch(error => logger.add(`[ERROR|Task|sync] delete expired file error: ${error.stack}`)) : await (0, _File.createDirectory)(pathOutput, pathOutputStat);
    logger.add(`[Task|sync] start: ${JSON.stringify(inputData)}`);
    const {id: taskId, promise: taskPromise} = taskRunner.startTask(inputData);
    taskPromise && await taskPromise;
    const {error} = taskRunner.getTaskState(taskId);
    if (error) throw error;
  }
  logger.add(`[Task|sync] end: ${fileName}`);
  return {
    pathFile,
    routeFile: (0, _path.join)("/", routeOutput, fileName)
  };
});
const SNAPSHOT_TASK_MODE_LIST = [ "thumbnail", "zoom-0.50", "zoom-1.00", "zoom-2.00" ];
const fetchSyncTaskInputData = async (searchParams, headers, urlSnapshotTask) => {
  const mode = searchParams.get("mode") || "thumbnail";
  if (!SNAPSHOT_TASK_MODE_LIST.includes(mode)) throw new Error(`[fetchSyncTaskInputData] invalid mode: ${mode}`);
  const url = `${urlSnapshotTask}?${new _url.URLSearchParams({
    mode,
    access_token: searchParams.get("access-token"),
    screen_cid: searchParams.get("screen-cid"),
    screenstate_cid: searchParams.get("screenstate-cid") || "default"
  })}`;
  const response = await (0, _net.fetch)(url, {
    method: "GET",
    headers: {
      cookie: headers.cookie || ""
    }
  });
  if (!response.ok) throw new Error(`[fetchSyncTaskInputData] fetch failed, url: ${url}, status: ${response.status}`);
  const inputData = await response.json();
  if (inputData.taskList && 1 !== inputData.taskList.length) throw new Error("expect to get single task taskList");
  return inputData;
};
const deleteFileWithPrefix = async (directoryPath, prefix) => {
  for (const {path, name} of await (0, _Directory.getDirectorySubInfoList)(directoryPath)) name.startsWith(prefix) && await unlinkAsync(path);
};