var _puppeteer = function(obj) {
  return obj && obj.__esModule ? obj : {
    default: obj
  };
}(require("puppeteer"));
var _net = require("dr-js/library/node/net");
var _snapshot = require("./snapshot");
const DEFAULT_TIMEOUT_OPTION = {
  timeout: 1e4
};
exports.createTaskRunnerOptionPuppeteer = (({urlSnapshotApp, urlServerPingTest, puppeteerBrowser, logger}) => {
  let puppeteerPage = null;
  const resetRunner = (error, taskId) => {
    error && logger.add(`[Puppeteer|${taskId}] error: ${error.stack || error.toString()}`);
    return puppeteerPage && clearPuppeteerPage({
      puppeteerPage
    }).then(() => {
      puppeteerPage = null;
    });
  };
  return {
    clearRunner: resetRunner,
    resetRunner,
    getTaskInitialState: task => ({
      ...task,
      progress: 0
    }),
    runTask: async (taskId, {getTaskState, updateTaskState}) => {
      puppeteerPage || (puppeteerPage = await initPuppeteerPage({
        puppeteerBrowser,
        logger
      }));
      logger.add(`[Puppeteer|${taskId}] start`);
      await (0, _net.ping)({
        url: urlServerPingTest,
        wait: 2e3,
        maxRetry: 4
      });
      puppeteerPage.url().includes(urlSnapshotApp) || await setupPuppeteerPage({
        urlSnapshotApp,
        puppeteerPage,
        logger
      });
      const {inputData} = getTaskState(taskId);
      const outputData = await (0, _snapshot.doSnapshot)({
        inputData,
        puppeteerPage,
        logger,
        stepCallback: ({progress}) => updateTaskState(taskId, {
          progress
        })
      });
      logger.add(`[Puppeteer|${taskId}] complete`);
      return outputData;
    }
  };
});
exports.clearPuppeteerBrowser = (({puppeteerBrowser}) => {
  puppeteerBrowser.removeListener("disconnected", puppeteerBrowserDisconnectListener);
  return puppeteerBrowser.close().catch(error => {});
});
exports.initPuppeteerBrowser = (async ({logger}) => {
  logger.add("Puppeteer|Browser] init");
  const puppeteerBrowser = await _puppeteer.default.launch({
    args: [ "--no-sandbox" ],
    headless: !0,
    handleSIGHUP: !1,
    handleSIGINT: !1,
    handleSIGTERM: !1
  });
  puppeteerBrowser.addListener("disconnected", puppeteerBrowserDisconnectListener);
  logger.add("Puppeteer|Browser] init complete");
  return puppeteerBrowser;
});
const puppeteerBrowserDisconnectListener = () => {
  process.exit(-1);
};
const clearPuppeteerPage = ({puppeteerPage}) => puppeteerPage.close().catch(error => {});
const initPuppeteerPage = async ({puppeteerBrowser, logger}) => {
  logger.add("[Puppeteer|Page] init start");
  const puppeteerPage = await puppeteerBrowser.newPage();
  puppeteerPage.on("error", error => logger.add("[Puppeteer|Page] error:", error));
  puppeteerPage.on("pageerror", exceptionMessage => logger.add("[Puppeteer|Page] pageerror:", exceptionMessage));
  puppeteerPage.on("requestfailed", request => logger.add("[Puppeteer|Page] requestfailed:", {
    url: request.url(),
    method: request.method()
  }));
  puppeteerPage.on("console", consoleMessage => logger.add("[Puppeteer|Page] console:", consoleMessage.type(), consoleMessage.text()));
  logger.add("[Puppeteer|Page] init complete");
  return puppeteerPage;
};
const setupPuppeteerPage = async ({urlSnapshotApp, puppeteerPage, logger}) => {
  logger.add("[Puppeteer|Page] setup start");
  await puppeteerPage.goto(urlSnapshotApp, {
    waitUntil: "networkidle2",
    ...DEFAULT_TIMEOUT_OPTION
  });
  await puppeteerPage.setUserAgent("Phantom WebKit");
  await puppeteerPage.setViewport({
    width: 0,
    height: 0
  });
  await puppeteerPage.waitForFunction(_snapshot.BROWSER_FUNCTION_MAP.checkReady, DEFAULT_TIMEOUT_OPTION);
  logger.add("[Puppeteer|Page] setup ready");
};