Object.defineProperty(exports, "BROWSER_FUNCTION_MAP", {
  enumerable: !0,
  get: function() {
    return _BROWSER_FUNCTION.BROWSER_FUNCTION_MAP;
  }
});
var _path = require("path");
var _BROWSER_FUNCTION = require("./BROWSER_FUNCTION");
const DEFAULT_PAGE_FUNCTION_TIMEOUT_OPTION = {
  timeout: 1e4
};
exports.doSnapshot = (async ({puppeteerPage, inputData, stepCallback, logger}) => {
  const {projectCid, canvasZoom, canvasClip, taskList, pathOutput} = inputData;
  taskList.forEach(v => v.screenStateCid = v.screenStateCid || "default");
  await puppeteerPage.waitForFunction(_BROWSER_FUNCTION.BROWSER_FUNCTION_MAP.checkReady, DEFAULT_PAGE_FUNCTION_TIMEOUT_OPTION);
  await puppeteerPage.evaluate(_BROWSER_FUNCTION.BROWSER_FUNCTION_MAP.addSnapShotTask, {
    projectCid,
    canvasZoom,
    canvasClip,
    taskList
  });
  const outputList = [];
  const indexMax = taskList.length;
  for (let index = 0; index < indexMax; index++) {
    const snapshotTask = async () => {
      logger.add(`[snapshot|${index + 1}/${indexMax}] wait for puppeteerPage render`);
      await puppeteerPage.waitForFunction(_BROWSER_FUNCTION.BROWSER_FUNCTION_MAP.checkWait, DEFAULT_PAGE_FUNCTION_TIMEOUT_OPTION);
      const {canvasData, error} = await puppeteerPage.evaluate(_BROWSER_FUNCTION.BROWSER_FUNCTION_MAP.getTaskResult);
      if (error || !canvasData) {
        logger.add(`[snapshot|${index + 1}/${indexMax}] error: ${error}, canvasData: ${JSON.stringify(canvasData)}`);
        await puppeteerPage.evaluate(_BROWSER_FUNCTION.BROWSER_FUNCTION_MAP.sendReset);
        throw error;
      }
      const {screenCid, screenStateCid, canvasWidth, canvasHeight} = canvasData;
      const task = taskList.find(v => v.screenCid === screenCid && v.screenStateCid === screenStateCid);
      if (!task) throw new Error(`[snapshot] error getting task: ${JSON.stringify({
        taskList,
        canvasData
      })}`);
      const {fileName} = task;
      const pageClip = {
        x: 0,
        y: 0,
        width: canvasWidth,
        height: canvasHeight,
        ...canvasClip
      };
      const filePath = (0, _path.join)(pathOutput, fileName || `${screenCid}-${screenStateCid}_${canvasZoom}_${pageClip.width}_${pageClip.height}.png`);
      await puppeteerPage.screenshot({
        path: filePath,
        clip: pageClip
      });
      await puppeteerPage.evaluate(_BROWSER_FUNCTION.BROWSER_FUNCTION_MAP.sendResume);
      outputList.push({
        screenCid,
        screenStateCid,
        canvasZoom,
        canvasClip,
        fileName,
        filePath
      });
      stepCallback({
        progress: Math.round(100 * (index + 1) / indexMax)
      });
      logger.add(`[snapshot|${index + 1}/${indexMax}] file ready: ${filePath}`);
    };
    await Promise.race([ snapshotTask(), new Promise((resolve, reject) => setTimeout(() => reject(new Error("[TIMEOUT] snapshot task timeout after 20000")), 2e4)) ]);
  }
  return outputList;
});